
#include <windows.h>
#include <string>
#include <SDL.h>
#include "Tools.h"
#include "SDLgraph.h"
#include "main.h"

using namespace std;

const int JOYSTICK_DEAD_ZONE = 8000;

SDL_Renderer *SDLren = NULL;

SDL_Joystick* gGameController = NULL;
SDL_Haptic* gControllerHaptic = NULL;

int main(int argc, char** argv)
{


	if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC ) == -1) error("SDL_Init");




		//Check for joysticks
		if( SDL_NumJoysticks() < 1 )
		{
			error( "Warning: No joysticks connected!" );
		}
			//Load joystick

		gGameController = SDL_JoystickOpen( 0 );
		if( gGameController == NULL ) error( "Unable to open game controller! SDL Error: \n"+ (string) SDL_GetError() );

		
		
		//Get controller haptic device
				gControllerHaptic = SDL_HapticOpenFromJoystick( gGameController );
				if( gControllerHaptic == NULL )
				{
					error( "Controller does not support haptics! SDL Error: \n" + (string)SDL_GetError() );
				}
					//Get initialize rumble
					if( SDL_HapticRumbleInit( gControllerHaptic ) < 0 )
					{
						error( "Warning: Unable to initialize rumble! SDL Error: \n" + (string) SDL_GetError() );
					}





	SDL_Window *SDLwin = NULL;
	SDLwin = SDL_CreateWindow("Gamepad Test", SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED, 800, 600, NULL);
	if (!SDLwin) error("SDL_CreateWindow");
	
	SDLren = SDL_CreateRenderer(SDLwin, -1, SDL_RENDERER_ACCELERATED | SDL_RENDERER_PRESENTVSYNC); 
	if (!SDLren) error("SDL_CreateRenderer");





	SDL_Texture* image = LoadTexture("test.bmp");

	SDL_Texture* sprite = LoadTexture("pinguing.bmp");

	int X=100;
	int Y=100;


				//Normalized direction
			int xDir = 0;
			int yDir = 0;


	
	bool quit=false;
	while (!quit)
	{

		SDL_Event e;
		while (SDL_PollEvent(&e))
		{
			switch(e.type) 
			{
				case SDL_QUIT: { quit = true; } break;
				case SDL_KEYDOWN: 
				{
					switch (e.key.keysym.sym)
					{
						case SDLK_ESCAPE: {quit = true;} break;
						default: break;
					}
				} break;
				case SDL_JOYBUTTONDOWN:
				{
						//Play rumble at 75% strenght for 500 milliseconds
						if( SDL_HapticRumblePlay( gControllerHaptic, 0.75, 500 ) != 0 )
						{
							error( "Unable to play rumble! \n"+(string) SDL_GetError() );
						}
				} break;
				case SDL_JOYAXISMOTION:
				{
						//Motion on controller 0
						if( e.jaxis.which == 0 )
						{						
							//X axis motion
							if( e.jaxis.axis == 0 )
							{
								//Left of dead zone
								if( e.jaxis.value < -JOYSTICK_DEAD_ZONE )
								{
									xDir = -1;
								}
								//Right of dead zone
								else if( e.jaxis.value > JOYSTICK_DEAD_ZONE )
								{
									xDir =  1;
								}
								else
								{
									xDir = 0;
								}
							}
							//Y axis motion
							else if( e.jaxis.axis == 1 )
							{
								//Below of dead zone
								if( e.jaxis.value < -JOYSTICK_DEAD_ZONE )
								{
									yDir = -1;
								}
								//Above of dead zone
								else if( e.jaxis.value > JOYSTICK_DEAD_ZONE )
								{
									yDir =  1;
								}
								else
								{
									yDir = 0;
								}
							}
						}
					} break;

				default: break;
			}
		}



		X+=xDir;
		Y+=yDir;


        SDL_SetRenderDrawColor(SDLren, 0, 0, 0, 255);
		SDL_RenderClear(SDLren);

        
		
		SDL_RenderCopy(SDLren, image, NULL, NULL);

        
		SDL_Rect r;
		SDL_QueryTexture(sprite, NULL, NULL, &r.w, &r.h);
		r.x=X;
		r.y=Y;
		SDL_RenderCopy(SDLren, sprite, NULL, &r);
		
		
		SDL_RenderPresent(SDLren);


	}


	
    SDL_DestroyTexture(image);

	//Close game controller
	SDL_HapticClose( gControllerHaptic );
	SDL_JoystickClose( gGameController );

	SDL_DestroyRenderer(SDLren);
	SDL_DestroyWindow(SDLwin);
	
	SDL_Quit();



	return 0;
}